from .base_enum import BaseEnum


class GameMode(BaseEnum):
    STANDARD = "SoloStandard"
    ONE_SABER = "OneSaber"
    NO_ARROWS = "NoArrows"
    DEGREE_90 = "90Degree"
    DEGREE_360 = "360Degree"
    LIGHTSHOW = "SoloLightshow"
    LAWLESS = "SoloLawless"
    UNKNOWN = "Unknown"
